# MS-RAFT+

## Original code

[https://github.com/cv-stuttgart/MS_RAFT_plus](https://github.com/cv-stuttgart/MS_RAFT_plus)

## Additional requirements

In order to use MS-RAFT+ you need to install the alt_cuda_corr package.
Follow the instructions at [ptlflow/utils/external/alt_cuda_corr/README.md](../../../ptlflow/utils/external/alt_cuda_corr/README.md).

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

[CC BY-NC-SA 3.0 license.](https://creativecommons.org/licenses/by-nc-sa/3.0/)

## Citation

```
@techreport{jahediHighResolutionMultiScaleRAFT2022,
  title = {High-Resolution Multi-Scale {{RAFT}}},
  author = {Jahedi, Azin and Luz, Maximilian and Mehl, Lukas and Rivinius, Marc and Bruhn, Andr{\'e}s},
  year = {2022},
  month = oct,
  eprint = {2210.16900},
  eprinttype = {arxiv},
  primaryclass = {cs},
  pages = {3},
  archiveprefix = {arXiv},
  langid = {english},
  keywords = {Computer Science - Computer Vision and Pattern Recognition},
}
```